@@ -70,9 +70,7 @@ class UrlParser(object):
         filtered_paths = set()
         base_path = self.__get_base_path__(root_paths)
         for path in root_paths:
-            if path.startswith(base_path):
-                path = path[len(base_path):]
-            resource = path.split('/')[0]
+            resource = path.replace(base_path, '').split('/')[0]
             filtered_paths.add(base_path + resource)
 
         return list(filtered_paths)
