@@ -54,8 +54,10 @@ class SwaggerUIView(View):
             'swagger_settings': {
                 'discovery_url': "%sapi-docs/" % request.build_absolute_uri(),
                 'api_key': SWAGGER_SETTINGS.get('api_key', ''),
+                'token_type': SWAGGER_SETTINGS.get('token_type'),
                 'enabled_methods': mark_safe(
-                    json.dumps(SWAGGER_SETTINGS.get('enabled_methods')))
+                    json.dumps(SWAGGER_SETTINGS.get('enabled_methods'))),
+                'doc_expansion': SWAGGER_SETTINGS.get('doc_expansion', ''),
             }
         }
         response = render_to_response(template_name, RequestContext(request, data))
